build_and_install_plugin

Function build_and_install_plugin 

pub fn build_and_install_plugin(
    spec: &PluginInstallSpec,
    is_debug: bool,
) -> Result<()>
Build a Zellij WASM plugin and copy it into the local Zellij plugins directory.

Errors

Returns an error when the WASM target cannot be installed, the plugin build fails, or the artifact cannot be copied.