build_and_install_plugin_copies

Function build_and_install_plugin_copies 

pub fn build_and_install_plugin_copies(
    spec: &PluginInstallSpec,
    install_names: &[&str],
    is_debug: bool,
) -> Result<()>
Build a Zellij WASM plugin once and copy it into the local Zellij plugins directory under multiple names.

Errors

Returns an error when the WASM target cannot be installed, the plugin build fails, or any artifact copy fails.