pub fn install_layout_file(source: &Path, layout_name: &str) -> Result<()>Expand description
Copy a Zellij layout file into the local Zellij layouts directory.
Errors
Returns an error when the install directory cannot be resolved or created, or the layout file cannot be copied.